@@ -29,5 +29,5 @@ class Command(NoArgsCommand):
                 if field.empty_strings_allowed:
                     q |= Q(**{def_lang_fieldname: ""})
 
-                model.objects.filter(q).rewrite(False).update(
+                model._default_manager.filter(q).rewrite(False).update(
                     **{def_lang_fieldname: F(field_name)})
