@@ -1,15 +1,16 @@
 # -*- coding: utf-8 -*-
 from django.utils.six import with_metaclass
+from django.core.exceptions import ImproperlyConfigured
 from django.db.models import Manager, ForeignKey, OneToOneField
 from django.db.models.base import ModelBase
 from django.db.models.signals import post_init
-from django.dispatch import receiver
 
 from modeltranslation import settings as mt_settings
 from modeltranslation.fields import (NONE, create_translation_field, TranslationFieldDescriptor,
                                      TranslatedRelationIdDescriptor,
                                      LanguageCacheSingleObjectDescriptor)
-from modeltranslation.manager import MultilingualManager, rewrite_lookup_key
+from modeltranslation.manager import (MultilingualManager, MultilingualQuerysetManager,
+                                      rewrite_lookup_key)
 from modeltranslation.utils import build_localized_fieldname, parse_field
 
 
@@ -58,6 +59,7 @@ class TranslationOptions(with_metaclass(FieldsAggregationMetaClass, object)):
     with translated model. This model may be not translated itself.
     ``related_fields`` contains names of reverse lookup fields.
     """
+    required_languages = ()
 
     def __init__(self, model):
         """
@@ -70,6 +72,28 @@ class TranslationOptions(with_metaclass(FieldsAggregationMetaClass, object)):
         self.fields = dict((f, set()) for f in self.fields)
         self.related_fields = []
 
+    def validate(self):
+        """
+        Perform options validation.
+        """
+        # TODO: at the moment only required_languages is validated.
+        # Maybe check other options as well?
+        if self.required_languages:
+            if isinstance(self.required_languages, (tuple, list)):
+                self._check_languages(self.required_languages)
+            else:
+                self._check_languages(self.required_languages.keys(), extra=('default',))
+                for fieldnames in self.required_languages.values():
+                    if any(f not in self.fields for f in fieldnames):
+                        raise ImproperlyConfigured(
+                            'Fieldname in required_languages which is not in fields option.')
+
+    def _check_languages(self, languages, extra=()):
+        correct = list(mt_settings.AVAILABLE_LANGUAGES) + list(extra)
+        if any(l not in correct for l in languages):
+            raise ImproperlyConfigured(
+                'Language in required_languages which is not in AVAILABLE_LANGUAGES.')
+
     def update(self, other):
         """
         Update with options from a superclass.
@@ -129,6 +153,13 @@ def add_translation_fields(model, opts):
         model._meta._fill_fields_cache()
 
 
+def has_custom_queryset(manager):
+    "Check whether manager (or its parents) has declared some custom get_queryset method."
+    old_diff = getattr(manager, 'get_query_set', None) != getattr(Manager, 'get_query_set', None)
+    new_diff = getattr(manager, 'get_queryset', None) != getattr(Manager, 'get_queryset', None)
+    return old_diff or new_diff
+
+
 def add_manager(model):
     """
     Monkey patches the original model to use MultilingualManager instead of
@@ -138,16 +169,31 @@ def add_manager(model):
     """
     if model._meta.abstract:
         return
+
+    def patch_manager_class(manager):
+        if isinstance(manager, MultilingualManager):
+            return
+        if manager.__class__ is Manager:
+            manager.__class__ = MultilingualManager
+        else:
+            class NewMultilingualManager(MultilingualManager, manager.__class__,
+                                         MultilingualQuerysetManager):
+                use_for_related_fields = getattr(
+                    manager.__class__, "use_for_related_fields", not has_custom_queryset(manager))
+            manager.__class__ = NewMultilingualManager
+
     for _, attname, cls in model._meta.concrete_managers + model._meta.abstract_managers:
         current_manager = getattr(model, attname)
-        if isinstance(current_manager, MultilingualManager):
-            continue
-        if current_manager.__class__ is Manager:
-            current_manager.__class__ = MultilingualManager
-        else:
-            class NewMultilingualManager(MultilingualManager, current_manager.__class__):
-                pass
-            current_manager.__class__ = NewMultilingualManager
+        prev_class = current_manager.__class__
+        patch_manager_class(current_manager)
+        if model._default_manager.__class__ is prev_class:
+            # Normally model._default_manager is a reference to one of model's managers
+            # (and would be patched by the way).
+            # However, in some rare situations (mostly proxy models)
+            # model._default_manager is not the same instance as one of managers, but it
+            # share the same class.
+            model._default_manager.__class__ = current_manager.__class__
+    patch_manager_class(model._base_manager)
 
 
 def patch_constructor(model):
@@ -168,7 +214,6 @@ def patch_constructor(model):
     model.__init__ = new_init
 
 
-@receiver(post_init)
 def delete_mt_init(sender, instance, **kwargs):
     if hasattr(instance, '_mt_init'):
         del instance._mt_init
@@ -336,12 +381,18 @@ class Translator(object):
             # Find inherited fields and create options instance for the model.
             opts = self._get_options_for_model(model, opts_class, **options)
 
+            # Now, when all fields are initialized and inherited, validate configuration.
+            opts.validate()
+
             # Mark the object explicitly as registered -- registry caches
             # options of all models, registered or not.
             opts.registered = True
 
             # Add translation fields to the model.
-            add_translation_fields(model, opts)
+            if model._meta.proxy:
+                delete_cache_fields(model)
+            else:
+                add_translation_fields(model, opts)
 
             # Delete all fields cache for related model (parent and children)
             for related_obj in model._meta.get_all_related_objects():
@@ -353,6 +404,9 @@ class Translator(object):
             # Patch __init__ to rewrite fields
             patch_constructor(model)
 
+            # Connect signal for model
+            post_init.connect(delete_mt_init, sender=model)
+
             # Patch clean_fields to verify form field clearing
             patch_clean_fields(model)
 
@@ -432,6 +486,8 @@ class Translator(object):
         Returns an instance of translation options with translated fields
         defined for the ``model`` and inherited from superclasses.
         """
+        if model._deferred:
+            model = model._meta.proxy_for_model
         if model not in self._registry:
             # Create a new type for backwards compatibility.
             opts = type("%sTranslationOptions" % model.__name__,
